@@ -6,12 +6,12 @@
 
 #include "org.kde.ActivityManager.Activities.h"
 
-#include <QMetaType>
 #include <QDBusMetaType>
 
-namespace details {
-
-class ActivityInfoStaticInit {
+namespace details
+{
+class ActivityInfoStaticInit
+{
 public:
     ActivityInfoStaticInit()
     {
