@@ -102,7 +102,7 @@ public:
 Application *Application::Private::s_instance = nullptr;
 
 Application::Application(int &argc, char **argv)
-    : QApplication(argc, argv)
+    : QGuiApplication(argc, argv)
 {
 }
 
@@ -193,7 +193,7 @@ Application::~Application()
     qCDebug(KAMD_LOG_APPLICATION) << "Cleaning up...";
 
     // Waiting for the threads to finish
-    for (const auto thread : s_moduleThreads) {
+    for (const auto thread : std::as_const(s_moduleThreads)) {
         thread->quit();
         thread->wait();
 
@@ -201,7 +201,7 @@ Application::~Application()
     }
 
     // Deleting plugin objects
-    for (const auto plugin : d->plugins) {
+    for (const auto plugin : std::as_const(d->plugins)) {
         delete plugin;
     }
 
@@ -234,7 +234,7 @@ Resources &Application::resources() const
 
 void Application::quit()
 {
-    QApplication::quit();
+    QCoreApplication::quit();
 }
 
 #include "Version.h"
