@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef PLUGIN_H
-#define PLUGIN_H
+#pragma once
 
 #include "kactivitymanagerd_plugin_export.h"
 
@@ -67,11 +66,11 @@ public:
     // }
 
     template<typename ReturnType, typename... Args>
-    inline static ReturnType retrieve(QObject *object, const char *method, const char *returnTypeName, Args... args)
+    inline static ReturnType retrieve(QObject *object, const char *method, Args... args)
     {
         ReturnType result;
 
-        QMetaObject::invokeMethod(object, method, Qt::DirectConnection, QReturnArgument<ReturnType>(returnTypeName, result), args...);
+        QMetaObject::invokeMethod(object, method, Qt::DirectConnection, Q_RETURN_ARG(ReturnType, result), args...);
 
         return result;
     }
@@ -99,5 +98,3 @@ protected:
 private:
     D_PTR;
 };
-
-#endif // PLUGIN_H
