@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PLUGINS_RUN_APPLICATION_PLUGIN_H
-#define PLUGINS_RUN_APPLICATION_PLUGIN_H
+#pragma once
 
 #include "dbusutils.h"
 #include <Plugin.h>
@@ -15,7 +14,7 @@ class ActivityRunner : public Plugin
     Q_OBJECT
 
 public:
-    explicit ActivityRunner(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit ActivityRunner(QObject *parent);
     ~ActivityRunner() override;
     bool init(QHash<QString, QObject *> &modules) override;
 
@@ -29,5 +28,3 @@ private:
     const QString m_keywordi18n;
     const QString m_keyword;
 };
-
-#endif // PLUGINS_RUN_APPLICATION_PLUGIN_H
